@@ -6,10 +6,26 @@ except ImportError:
     from importlib_metadata import PackageNotFoundError, version  # type: ignore  # noqa
 
 try:
-    from .c.c_ppmd import Ppmd7Decoder, Ppmd7Encoder, Ppmd8Decoder, Ppmd8Encoder, PpmdError  # noqa
+    from .c.c_ppmd import (  # noqa
+        PPMD8_RESTORE_METHOD_CUT_OFF,
+        PPMD8_RESTORE_METHOD_RESTART,
+        Ppmd7Decoder,
+        Ppmd7Encoder,
+        Ppmd8Decoder,
+        Ppmd8Encoder,
+        PpmdError,
+    )
 except ImportError:
     try:
-        from .cffi.cffi_ppmd import Ppmd7Decoder, Ppmd7Encoder, Ppmd8Decoder, Ppmd8Encoder, PpmdError  # noqa
+        from .cffi.cffi_ppmd import (  # noqa
+            PPMD8_RESTORE_METHOD_CUT_OFF,
+            PPMD8_RESTORE_METHOD_RESTART,
+            Ppmd7Decoder,
+            Ppmd7Encoder,
+            Ppmd8Decoder,
+            Ppmd8Encoder,
+            PpmdError,
+        )
     except ImportError:
         msg = "pyppmd module: Neither C implementation nor CFFI " "implementation can be imported."
         raise ImportError(msg)
@@ -36,8 +52,10 @@ except PackageNotFoundError:  # pragma: no-cover
 class PpmdCompressor:
     """Compressor class to compress data by PPMd algorithm."""
 
-    def __init__(self, max_order: int = 6, mem_size: int = 8 << 20):
-        self.encoder = Ppmd8Encoder(max_order, mem_size)
+    def __init__(
+        self, max_order: int = 6, mem_size: int = 8 << 20, restore_method=PPMD8_RESTORE_METHOD_RESTART, endmark=True
+    ):
+        self.encoder = Ppmd8Encoder(max_order, mem_size, restore_method, endmark)
         self.eof = False
 
     def compress(self, data_or_str: Union[bytes, bytearray, memoryview, str]):
@@ -57,8 +75,10 @@ class PpmdCompressor:
 class PpmdDecompressor:
     """Decompressor class to decompress data by PPMd algorithm."""
 
-    def __init__(self, max_order: int = 6, mem_size: int = 8 << 20):
-        self.decoder = Ppmd8Decoder(max_order=max_order, mem_size=mem_size)
+    def __init__(
+        self, max_order: int = 6, mem_size: int = 8 << 20, restore_method=PPMD8_RESTORE_METHOD_RESTART, endmark=True
+    ):
+        self.decoder = Ppmd8Decoder(max_order=max_order, mem_size=mem_size, restore_method=restore_method, endmark=endmark)
         self.eof = False
         self.need_input = True
 
